yl_stft_cfg class final

Inheritance
Implemented types
Available extensions

Constructors

yl_stft_cfg()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
center int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hop int
getter/setter pair
mean_subtract int
getter/setter pair
n_fft int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
win yl_window_type
no setter
win_len int
getter/setter pair
winAsInt int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited