autocorrOutLen static method
Returns the output length for direct autocorrelation in mode.
Implementation
static int autocorrOutLen(int n, {CorrOutMode mode = CorrOutMode.full}) =>
yl_autocorr_out_len_ffi(n, mode.value);
Returns the output length for direct autocorrelation in mode.
static int autocorrOutLen(int n, {CorrOutMode mode = CorrOutMode.full}) =>
yl_autocorr_out_len_ffi(n, mode.value);