outLen static method

int outLen(
  1. int nx,
  2. int nh
)

Returns the output length of a convolution or cross-correlation operation.

nx is the input length and nh is the filter/kernel length.

Implementation

static int outLen(int nx, int nh) => yl_conv_out_len_ffi(nx, nh);