CorrOutMode enum
Values
- full → const CorrOutMode
-
Full linear result (includes all overlap positions).
const CorrOutMode(0) - valid → const CorrOutMode
-
Only positions with complete overlap.
const CorrOutMode(1) - same → const CorrOutMode
-
Output length equals first input length, centered w.r.t. full.
const CorrOutMode(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CorrOutMode> - A constant List of the values in this enum, in order of their declaration.