SpecMode enum

Output representation for scalar spectra.

Used by FFTStatic.rfftMag, RfftPlan.executeSpec, and RfftPlan.executeSpecInto.

Inheritance
Available extensions

Values

mag → const SpecMode

Magnitude spectrum: sqrt(re^2 + im^2).

const SpecMode(1)
power → const SpecMode

Power spectrum: re^2 + im^2.

const SpecMode(2)
db → const SpecMode

Log-power spectrum in dB with floor clipping.

const SpecMode(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SpecMode>
A constant List of the values in this enum, in order of their declaration.