Resample class

Convenience API for one-off resampling operations.

Use this when you only need to resample a single block and do not want to retain native state between calls.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

process(Float32List input, {required int origFreq, required int newFreq, int lowpassFilterWidth = 6, double rolloff = 0.99, ResamplingMethod method = ResamplingMethod.sincHann, double? beta}) Float32List
Resamples a single block of audio from origFreq to newFreq.