asComplex method
Wraps the flattened real and imaginary buffers as a complex vector view.
Implementation
Complex32List asComplex() => Complex32List.wrap(real, imag);
Wraps the flattened real and imaginary buffers as a complex vector view.
Complex32List asComplex() => Complex32List.wrap(real, imag);