WavReader class

Constructors

WavReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

readBytes(Uint8List bytes) WavData
Read a WAV from bytes (e.g., network, asset, or file you already loaded).
readFile(String path) Future<WavData>
Convenience: read from a file path.