WavWriter class

Constructors

WavWriter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodeBytes(Float32List samples, {required int sampleRate, required int channels, int audioFormat = 1, int bitsPerSample = 16}) Uint8List
Encode normalized -1,1 float samples (interleaved) into a WAV byte buffer.
writeFile(String path, Float32List samples, {required int sampleRate, required int channels, int audioFormat = 1, int bitsPerSample = 16}) Future<void>
Convenience: write to a file.