NativeHandle<R extends NativeResource> class abstract

Implementers

Constructors

NativeHandle(R res)

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether close() has been called.
no setter
res → R
Throws if closed; returns the native resource otherwise.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Deterministic cleanup.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited