SignalGenerator class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

arange(num startOrStop, [num? stop, num step = 1]) Float32List
cosine({required int n, required double freqHz, required double sampleRate, double amplitude = 1.0, double phaseRad = 0.0}) Float32List
exponentialSweep({required int n, required double fStart, required double fEnd, required double sampleRate, double amplitude = 1.0}) Float32List
lcgNoise(int n, {double amplitude = 1.0, int seed = 123456789}) Float32List
linearSweep({required int n, required double fStart, required double fEnd, required double sampleRate, double amplitude = 1.0}) Float32List
linspace(double start, double stop, {int num = 50, bool endpoint = true}) Float32List
Generates a sequence of evenly spaced values over a specified interval.
pulseTrain({required int n, required double freqHz, required double sampleRate, double amplitude = 1.0, double dutyCycle = 0.5}) Float32List
sawtooth({required int n, required double freqHz, required double sampleRate, double amplitude = 1.0}) Float32List
sine({required int n, required double freqHz, required double sampleRate, double amplitude = 1.0, double phaseRad = 0.0}) Float32List
whiteNoise(int n, {double amplitude = 1.0, int? seed}) Float32List