utils/windows library

Enums

WindowType
Supported scalar window functions for frame-based DSP operations.

Functions

applyWindow(Float32List input, {WindowType type = WindowType.hann, bool periodic = true}) Float32List
Returns a new array containing input multiplied by a generated window.
applyWindowInPlace(Float32List input, {WindowType type = WindowType.hann, bool periodic = true}) → void
Multiplies input in place by a generated window.
blackmanWindow(int length, {bool periodic = true}) Float32List
generateWindow(int length, {WindowType type = WindowType.hann, bool periodic = true}) Float32List
Returns a window of length for the selected type.
hammingWindow(int length, {bool periodic = true}) Float32List
hannWindow(int length, {bool periodic = true}) Float32List
multiplyWithWindow(Float32List input, Float32List window) Float32List
Returns a new array containing input[n] * window[n].
multiplyWithWindowInPlace(Float32List input, Float32List window) → void
Multiplies input by window in place.
rectWindow(int length, {bool periodic = true}) Float32List