Autocorr class

Inheritance

Constructors

Autocorr(int n, int inputLen)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputLen int
final
isClosed bool
Whether close() has been called.
no setterinherited
n int
final
res → _AutocorrRes
Throws if closed; returns the native resource otherwise.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Deterministic cleanup.
inherited
execute(Float32List input) Float32List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pitch(Float32List input, {double sample_rate = 16000, double fmin = 60, double fmax = 600}) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited