Conv class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
autocorrDirect(Float32List x, {CorrOutMode mode = CorrOutMode.full, bool simd = false})
→ Float32List
-
Direct O(n^2) autocorrelation in scipy-style output
mode.
-
autocorrOutLen(int n, {CorrOutMode mode = CorrOutMode.full})
→ int
-
Returns the output length for direct autocorrelation in
mode.
-
correlationLags(int in1Len, int in2Len, {CorrOutMode mode = CorrOutMode.full})
→ Int32List
-
Returns lag indices equivalent to
scipy.signal.correlation_lags.
-
direct(Float32List x, Float32List h, {ConvMode mode = ConvMode.convolution, CorrOutMode outMode = CorrOutMode.full, bool simd = false})
→ Float32List
-
Computes convolution or cross-correlation directly for one block of data.
-
outLen(int nx, int nh)
→ int
-
Returns the output length of a convolution or cross-correlation operation.
-
outLenMode(int nx, int nh, {CorrOutMode outMode = CorrOutMode.full})
→ int
-
Returns output length for the selected scipy-style
outMode.