Returns the output length of a convolution or cross-correlation operation.
nx is the input length and nh is the filter/kernel length.
nx
nh
static int outLen(int nx, int nh) => yl_conv_out_len_ffi(nx, nh);