FindPeaksProperties class
Constructors
- FindPeaksProperties({Int64List? plateau_sizes, Int64List? left_edges, Int64List? right_edges, Float32List? peak_heights, Float32List? left_thresholds, Float32List? right_thresholds, Float32List? prominences, Int64List? left_bases, Int64List? right_bases, Float32List? widths, Float32List? width_heights, Float32List? left_ips, Float32List? right_ips})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- left_bases → Int64List?
-
final
- left_edges → Int64List?
-
final
- left_ips → Float32List?
-
final
- left_thresholds → Float32List?
-
final
- peak_heights → Float32List?
-
final
- plateau_sizes → Int64List?
-
final
- prominences → Float32List?
-
final
- right_bases → Int64List?
-
final
- right_edges → Int64List?
-
final
- right_ips → Float32List?
-
final
- right_thresholds → Float32List?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width_heights → Float32List?
-
final
- widths → Float32List?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited