WavData class
Constructors
Properties
- audioFormat → int
-
final
- bitsPerSample → int
-
final
- blockAlign → int
-
final
- byteRate → int
-
final
- channels → int
-
final
- durationSeconds → double
-
no setter
- frameCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
final
- samples → Float32List
-
Samples normalized to
-1, 1, interleaved:ch0, ch1, ..., chN, ch0, ch1, ...final
Methods
-
deinterleave(
) → List< Float32List> - Returns per-channel arrays (copies).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited